@@ -586,16 +586,21 @@ class RedisRoot:
     def check_cache(self):
         django_models_to_cache = self._get_django_models_to_cache()
         for django_model, cache_conf in django_models_to_cache.items():
+
+            print(f'{datetime.datetime.now()} - '
+                  f'Start caching {django_model}'
+                  f'\n')
+
             cache_func = cache_conf['cache_func']
-
             redis_model = self.get_or_create_redis_model_from_django_model(django_model)
-
             cache_func(
                 self,
                 django_model,
                 cache_conf,
             )
-            print(f'{datetime.datetime.now()} - Cached {django_model} successfully')
+            print(f'{datetime.datetime.now()} - '
+                  f'Cached {django_model} successfully'
+                  f'\n\n\n')
 
     def fast_get_keys_values(self, string):
         keys = list(self.redis_instance.scan_iter(string))
@@ -643,6 +648,7 @@ class RedisRoot:
             'cache_func': default_cache_func,
             'exclude_fields': [],
             'filter_by': {},
+            'write_to_django': False,
             'delete': False,
         }
         if user_cache_conf is not None:
@@ -690,6 +696,11 @@ class RedisRoot:
                             raise Exception(f'{name} -> cache config -> filter_by -> all keys must be strings')
                     else:
                         raise Exception(f'{name} -> cache config -> filter_by must be dict')
+                if 'write_to_django' in user_cache_conf.keys():
+                    if type(user_cache_conf['write_to_django']) == bool:
+                        cache_conf['write_to_django'] = user_cache_conf['write_to_django']
+                    else:
+                        raise Exception(f'{name} -> cache config -> write_to_django must be bool')
                 if 'delete' in user_cache_conf.keys():
                     if type(user_cache_conf['delete']) == bool:
                         cache_conf['delete'] = user_cache_conf['delete']
